Installation
============

toot is packaged for various platforms. If possible use your OS's package manager to install toot.

[![Packaging status](https://repology.org/badge/vertical-allrepos/toot.svg)](https://repology.org/project/toot/versions)

## Python Package Index

Install from PyPI using pip, preferably into a virtual environment.

    pip install toot

## Homebrew

For Mac OSX users, toot is available [in homebrew](https://formulae.brew.sh/formula/toot#default).

    brew install toot

## From source

You can get the latest source distribution [from Github](https://github.com/ihabunek/toot/releases/latest/).
